﻿<?php

/**
 *    Time Zones
 *
 *    LICENSE: BSD
 *
 *    @category   Time Zones
 *    @author     SELFPHP OHG <info@selfphp.de>
 *    @copyright  2001-20013 SELFPHP OHG
 *    @version    $Id: TimezonesClass.php,v 0.10 2013/08/13 16:19:21 des1 Exp $
 *    @link       http://www.selfphp.de
 */ 

class TimezonesClass{
	
	public function __construct()
	{
		
	}
	
	public function getSpecificTimeZone($value){
		
		$zones = $this->getTimeZonesIdentifier();
		
		if (array_key_exists($value, $zones)) {
			return $zones[$value];
		}
		else{
			return 'Europe/Dublin';
		}
	}
	
	public function get_timezone_difference($zone_1, $zone_2 = null) {
		
		$difference = array();
		
		if($zone_2 === null) {
			if( !is_string( $zone_2 = date_default_timezone_get() ) ) {
				return false;
			}
		}
		
		$zone_1_DTZ = new DateTimeZone($zone_1);
		$zone_2_DTZ = new DateTimeZone($zone_2);
		
		$zone_1_DT = new DateTime("now", $zone_1_DTZ);
		$zone_2_DT = new DateTime("now", $zone_2_DTZ);
		
		$difference['seconds'] = $zone_2_DTZ->getOffset($zone_2_DT) - $zone_1_DTZ->getOffset($zone_1_DT);
		$difference['hours'] = $difference['seconds'] / 3600;
		
		return $difference;
		
	}
	
	public function getTimeZonesIdentifier(){
		$zones = array(
				'-12' => 'Pacific/Kwajalein',
				'-11' => 'Pacific/Midway',
				'-10' => 'Pacific/Honolulu',
				'-9' => 'America/Anchorage',
				'-8' => 'America/Los_Angeles',
				'-7' => 'America/Denver',
				'-6' => 'America/Tegucigalpa',
				'-5' => 'America/New_York',
				'-4.5' => 'America/Caracas',
				'-4' => 'America/Halifax',
				'-3.5' => 'America/St_Johns',
				'-3' => 'America/Argentina/Buenos_Aires',
				'-2' => 'Atlantic/South_Georgia',
				'-1' => 'Atlantic/Azores',
				'0' => 'Europe/Dublin',
				'1' => 'Europe/Belgrade',
				'2' => 'Europe/Minsk',
				'3' => 'Asia/Kuwait',
				'3.5' => 'Asia/Tehran',
				'4' => 'Asia/Muscat',
				'4.5' => 'Asia/Kabul',
				'5' => 'Asia/Yekaterinburg',
				'5.5' => 'Asia/Kolkata',
				'5.75' => 'Asia/Katmandu',
				'6' => 'Asia/Dhaka',
				'6.5' => 'Asia/Rangoon',
				'7' => 'Asia/Krasnoyarsk',
				'8' => 'Asia/Brunei',
				'9' => 'Asia/Seoul',
				'9.5' => 'Australia/Darwin',
				'10' => 'Australia/Canberra',
				'11' => 'Asia/Magadan',
				'12' => 'Pacific/Fiji',
				'13' => 'Pacific/Tongatapu'
		);
		
		return $zones;
	}
	
	public function getTimeZonesDescription(){
	
		$zones = array(
				'-12' => '(WEZ -12:00) Eniwetok, Kwajalein',
				'-11' => '(WEZ -11:00) Midway Island, Samoa',
				'-10' => '(WEZ -10:00) Hawaii',
				'-9' => '(WEZ -9:00) Alaska',
				'-8' => '(WEZ -8:00) Pacific Time (USA & Kanada)',
				'-7' => '(WEZ -7:00) Mountain Time (USA & Kanada)',
				'-6' => '(WEZ -6:00) Central Time (USA & Kanada), Mexiko Stadt',
				'-5' => '(WEZ -5:00) Eastern Time (USA & Kanada), Bogota, Lima',
				'-4.5' => '(WEZ -4:30) Caracas',
				'-4' => '(WEZ -4:00) Atlantik (Kanada), La Paz, Santiago',
				'-3.5' => '(WEZ -3:30) Neufundland',
				'-3' => '(WEZ -3:00) Brasilien, Buenos Aires, Georgetown',
				'-2' => '(WEZ -2:00) Mittelatlantik',
				'-1' => '(WEZ -1:00) Azoren, Kap Verde Inseln',
				'0' => '(WEZ) Westeuropaeische Zeit, London, Lissabon, Casablanca',
				'1' => '(WEZ +1:00) Mitteleuropaeische Zeit (MEZ), Berlin, Madrid, Paris',
				'2' => '(WEZ +2:00) Kaliningrad, Suedafrika',
				'3' => '(WEZ +3:00) Baghdad, Riyadh, Moskau, St. Petersburg',
				'3.5' => '(WEZ +3:30) Teheran',
				'4' => '(WEZ +4:00) Abu Dhabi, Muscat, Baku, Tbilisi',
				'4.5' => '(WEZ +4:30) Kabul',
				'5' => '(WEZ +5:00) Ekaterinburg, Islamabad, Karachi, Tashkent',
				'5.5' => '(WEZ +5:30) Mumbai, Kalkutta, Chennai, Neu-Delhi',
				'5.75' => '(WEZ +5:45) Katmandu',
				'6' => '(WEZ +6:00) Almaty, Dhaka, Colombo',
				'6.5' => '(WEZ +6:30) Rangun, Kokosinseln',
				'7' => '(WEZ +7:00) Bangkok, Hanoi, Jakarta',
				'8' => '(WEZ +8:00) Peking, Perth, Singapur, Hong Kong',
				'9' => '(WEZ +9:00) Tokyo, Seoul, Osaka, Sapporo, Yakutsk',
				'9.5' => '(WEZ +9:30) Adelaide, Darwin',
				'10' => '(WEZ +10:00) Ostaustralien, Guam, Vladivostok',
				'11' => '(WEZ +11:00) Magadan, Solomon-Inseln, Neu Kaledonien',
				'12' => '(WEZ +12:00) Auckland, Wellington, Fidschi, Kamchatka',
				'13' => '(WEZ +13:00) Tongatapu'
		);
	
		return $zones;
	}
	
}